@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.0.15';
+our $VERSION = '0.0.16';
 
 
 1;
@@ -55,6 +55,14 @@ sub run_story_file {
 
         my $st = execute_cmd("perl $story_file 1>$content_file 2>&1 && test -f $content_file");
 
+
+        if ($ENV{outth_show_story}){
+            open STR, $story_file or die $!;
+            my $sdata = join "", <STR>;
+            close CNT;
+            note("story file:\n$sdata");
+        }
+
         if ($st) {
             ok(1, "perl $story_file succeeded");
         }elsif(ignore_story_err()){
@@ -1039,6 +1047,15 @@ C<match_l> - in TAP output truncate matching strings to {match_l} bytes
 
 See also `--match_l' in L<options|#options> section
 
+=over
+
+=item *
+
+C<outth_show_story> - if set, then content of story.pl file gets dumped in TAP output
+
+
+=back
+
 
 =head1 Examples
 
